@@ -6,7 +6,7 @@ import logging
 
 __author__ = """dem4ply"""
 __email__ = 'dem4ply@gmail.com'
-__version__ = '0.2.2'
+__version__ = '0.2.4'
 
 logger = logging.getLogger( 'chibi.command' )
 
@@ -82,6 +82,7 @@ class Command:
         arguments = self.build_tuple( *args, **kw )
         logger.debug(
             'coamndo con argumentos "{}"'.format( str( arguments  ) ) )
+        arguments = tuple( map( lambda x: str( x ), arguments ) )
         proc = Popen(
             arguments, stdin=stdin, stdout=self.stdout, stderr=self.stderr )
         return proc
@@ -92,16 +93,20 @@ class Command:
     def build_kw( self, **kw ):
         params = self.kw.copy()
         params.update( kw )
-        return tuple(
-            self.kw_format.format( key=k, value=v )
-            for k, v in params.items() )
+        result = []
+        for k, v in params.items():
+            r = self.kw_format.format( key=k, value=v )
+            r = r.split( ' ', 1 )
+            result += r
+        return result
 
     def preview( self, *args, **kw ):
         tuples = self.build_tuple( *args, **kw )
+        tuples = map( lambda x: str( x ), tuples )
         return " ".join( tuples )
 
     def run( self, *args, stdin=None, **kw ):
-        logger.info( 'ejecutando "{}"'.format( self.preview( *args, **kw ) ) )
+        logger.debug( 'ejecutando "{}"'.format( self.preview( *args, **kw ) ) )
         proc = self._build_proccess( *args, stdin=stdin, **kw )
 
         if isinstance( stdin, str ):
