@@ -70,14 +70,22 @@ class Rsync( Command ):
         self.options( '-u' )
         return self
 
+    @Chibi_hybrid
+    def ignore( cls ):
+        return cls.options( '-I' )
+
+    @update.instancemethod
+    def ignore( self ):
+        self.options( '-I' )
+        return self
+
     @Chibi_hybrid
     def clone_dir( cls ):
         instance = cls.archive_mode()
-        instance.compress()
         instance.update()
         return instance
 
     @clone_dir.instancemethod
     def clone_dir( self ):
-        self.archive_mode().compress().update()
+        self.archive_mode().update()
         return self
